# coding: utf-8

# flake8: noqa

"""
    Webhooks Webhooks

    Provides a way for apps to subscribe to certain change events in HubSpot. Once configured, apps will receive event payloads containing details about the changes at a specified target URL. There can only be one target URL for receiving event notifications per app.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.webhooks.api.settings_api import SettingsApi
from hubspot.webhooks.api.subscriptions_api import SubscriptionsApi

# import ApiClient
from hubspot.webhooks.api_client import ApiClient
from hubspot.webhooks.configuration import Configuration
from hubspot.webhooks.exceptions import OpenApiException
from hubspot.webhooks.exceptions import ApiTypeError
from hubspot.webhooks.exceptions import ApiValueError
from hubspot.webhooks.exceptions import ApiKeyError
from hubspot.webhooks.exceptions import ApiAttributeError
from hubspot.webhooks.exceptions import ApiException

# import models into sdk package
from hubspot.webhooks.models.batch_input_subscription_batch_update_request import BatchInputSubscriptionBatchUpdateRequest
from hubspot.webhooks.models.batch_response_subscription_response import BatchResponseSubscriptionResponse
from hubspot.webhooks.models.batch_response_subscription_response_with_errors import BatchResponseSubscriptionResponseWithErrors
from hubspot.webhooks.models.error import Error
from hubspot.webhooks.models.error_detail import ErrorDetail
from hubspot.webhooks.models.settings_change_request import SettingsChangeRequest
from hubspot.webhooks.models.settings_response import SettingsResponse
from hubspot.webhooks.models.standard_error import StandardError
from hubspot.webhooks.models.subscription_batch_update_request import SubscriptionBatchUpdateRequest
from hubspot.webhooks.models.subscription_create_request import SubscriptionCreateRequest
from hubspot.webhooks.models.subscription_list_response import SubscriptionListResponse
from hubspot.webhooks.models.subscription_patch_request import SubscriptionPatchRequest
from hubspot.webhooks.models.subscription_response import SubscriptionResponse
from hubspot.webhooks.models.throttling_settings import ThrottlingSettings



# coding: utf-8

"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.forms.configuration import Configuration


class FieldGroup(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"group_type": "str", "rich_text_type": "str", "rich_text": "str", "fields": "list[DependentFieldDependentField]"}

    attribute_map = {"group_type": "groupType", "rich_text_type": "richTextType", "rich_text": "richText", "fields": "fields"}

    def __init__(self, group_type=None, rich_text_type=None, rich_text=None, fields=None, local_vars_configuration=None):  # noqa: E501
        """FieldGroup - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._group_type = None
        self._rich_text_type = None
        self._rich_text = None
        self._fields = None
        self.discriminator = None

        self.group_type = group_type
        self.rich_text_type = rich_text_type
        if rich_text is not None:
            self.rich_text = rich_text
        self.fields = fields

    @property
    def group_type(self):
        """Gets the group_type of this FieldGroup.  # noqa: E501

          # noqa: E501

        :return: The group_type of this FieldGroup.  # noqa: E501
        :rtype: str
        """
        return self._group_type

    @group_type.setter
    def group_type(self, group_type):
        """Sets the group_type of this FieldGroup.

          # noqa: E501

        :param group_type: The group_type of this FieldGroup.  # noqa: E501
        :type group_type: str
        """
        if self.local_vars_configuration.client_side_validation and group_type is None:  # noqa: E501
            raise ValueError("Invalid value for `group_type`, must not be `None`")  # noqa: E501
        allowed_values = ["default_group", "progressive", "queued"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and group_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `group_type` ({0}), must be one of {1}".format(group_type, allowed_values))  # noqa: E501

        self._group_type = group_type

    @property
    def rich_text_type(self):
        """Gets the rich_text_type of this FieldGroup.  # noqa: E501

        The type of rich text included. The default value is text.  # noqa: E501

        :return: The rich_text_type of this FieldGroup.  # noqa: E501
        :rtype: str
        """
        return self._rich_text_type

    @rich_text_type.setter
    def rich_text_type(self, rich_text_type):
        """Sets the rich_text_type of this FieldGroup.

        The type of rich text included. The default value is text.  # noqa: E501

        :param rich_text_type: The rich_text_type of this FieldGroup.  # noqa: E501
        :type rich_text_type: str
        """
        if self.local_vars_configuration.client_side_validation and rich_text_type is None:  # noqa: E501
            raise ValueError("Invalid value for `rich_text_type`, must not be `None`")  # noqa: E501
        allowed_values = ["text", "image"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and rich_text_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `rich_text_type` ({0}), must be one of {1}".format(rich_text_type, allowed_values))  # noqa: E501

        self._rich_text_type = rich_text_type

    @property
    def rich_text(self):
        """Gets the rich_text of this FieldGroup.  # noqa: E501

        A block of rich text or an image. Those can be used to add extra information for the customers filling in the form. If the field group includes fields, the rich text will be displayed before the fields.  # noqa: E501

        :return: The rich_text of this FieldGroup.  # noqa: E501
        :rtype: str
        """
        return self._rich_text

    @rich_text.setter
    def rich_text(self, rich_text):
        """Sets the rich_text of this FieldGroup.

        A block of rich text or an image. Those can be used to add extra information for the customers filling in the form. If the field group includes fields, the rich text will be displayed before the fields.  # noqa: E501

        :param rich_text: The rich_text of this FieldGroup.  # noqa: E501
        :type rich_text: str
        """

        self._rich_text = rich_text

    @property
    def fields(self):
        """Gets the fields of this FieldGroup.  # noqa: E501

        The form fields included in the group  # noqa: E501

        :return: The fields of this FieldGroup.  # noqa: E501
        :rtype: list[DependentFieldDependentField]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this FieldGroup.

        The form fields included in the group  # noqa: E501

        :param fields: The fields of this FieldGroup.  # noqa: E501
        :type fields: list[DependentFieldDependentField]
        """
        if self.local_vars_configuration.client_side_validation and fields is None:  # noqa: E501
            raise ValueError("Invalid value for `fields`, must not be `None`")  # noqa: E501

        self._fields = fields

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FieldGroup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FieldGroup):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CRM Calling Extensions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.extensions.calling.configuration import Configuration


class SettingsPatchRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "supports_custom_objects": "bool",
        "uses_remote": "bool",
        "is_ready": "bool",
        "name": "str",
        "width": "int",
        "uses_calling_window": "bool",
        "supports_inbound_calling": "bool",
        "url": "str",
        "height": "int",
    }

    attribute_map = {
        "supports_custom_objects": "supportsCustomObjects",
        "uses_remote": "usesRemote",
        "is_ready": "isReady",
        "name": "name",
        "width": "width",
        "uses_calling_window": "usesCallingWindow",
        "supports_inbound_calling": "supportsInboundCalling",
        "url": "url",
        "height": "height",
    }

    def __init__(
        self,
        supports_custom_objects=None,
        uses_remote=None,
        is_ready=None,
        name=None,
        width=None,
        uses_calling_window=None,
        supports_inbound_calling=None,
        url=None,
        height=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SettingsPatchRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._supports_custom_objects = None
        self._uses_remote = None
        self._is_ready = None
        self._name = None
        self._width = None
        self._uses_calling_window = None
        self._supports_inbound_calling = None
        self._url = None
        self._height = None
        self.discriminator = None

        if supports_custom_objects is not None:
            self.supports_custom_objects = supports_custom_objects
        if uses_remote is not None:
            self.uses_remote = uses_remote
        if is_ready is not None:
            self.is_ready = is_ready
        if name is not None:
            self.name = name
        if width is not None:
            self.width = width
        if uses_calling_window is not None:
            self.uses_calling_window = uses_calling_window
        if supports_inbound_calling is not None:
            self.supports_inbound_calling = supports_inbound_calling
        if url is not None:
            self.url = url
        if height is not None:
            self.height = height

    @property
    def supports_custom_objects(self):
        """Gets the supports_custom_objects of this SettingsPatchRequest.  # noqa: E501

        When true, users will be able to click to dial from custom objects.  # noqa: E501

        :return: The supports_custom_objects of this SettingsPatchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._supports_custom_objects

    @supports_custom_objects.setter
    def supports_custom_objects(self, supports_custom_objects):
        """Sets the supports_custom_objects of this SettingsPatchRequest.

        When true, users will be able to click to dial from custom objects.  # noqa: E501

        :param supports_custom_objects: The supports_custom_objects of this SettingsPatchRequest.  # noqa: E501
        :type supports_custom_objects: bool
        """

        self._supports_custom_objects = supports_custom_objects

    @property
    def uses_remote(self):
        """Gets the uses_remote of this SettingsPatchRequest.  # noqa: E501

        When false, this indicates that your calling app does not use the anchored calling remote within the HubSpot app.   # noqa: E501

        :return: The uses_remote of this SettingsPatchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._uses_remote

    @uses_remote.setter
    def uses_remote(self, uses_remote):
        """Sets the uses_remote of this SettingsPatchRequest.

        When false, this indicates that your calling app does not use the anchored calling remote within the HubSpot app.   # noqa: E501

        :param uses_remote: The uses_remote of this SettingsPatchRequest.  # noqa: E501
        :type uses_remote: bool
        """

        self._uses_remote = uses_remote

    @property
    def is_ready(self):
        """Gets the is_ready of this SettingsPatchRequest.  # noqa: E501

        When true, this indicates that your calling app is ready for production. Users will be able to select your calling app as their provider and can then click to dial within HubSpot.  # noqa: E501

        :return: The is_ready of this SettingsPatchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_ready

    @is_ready.setter
    def is_ready(self, is_ready):
        """Sets the is_ready of this SettingsPatchRequest.

        When true, this indicates that your calling app is ready for production. Users will be able to select your calling app as their provider and can then click to dial within HubSpot.  # noqa: E501

        :param is_ready: The is_ready of this SettingsPatchRequest.  # noqa: E501
        :type is_ready: bool
        """

        self._is_ready = is_ready

    @property
    def name(self):
        """Gets the name of this SettingsPatchRequest.  # noqa: E501

        The name of your calling service to display to users.  # noqa: E501

        :return: The name of this SettingsPatchRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SettingsPatchRequest.

        The name of your calling service to display to users.  # noqa: E501

        :param name: The name of this SettingsPatchRequest.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def width(self):
        """Gets the width of this SettingsPatchRequest.  # noqa: E501

        The target width of the iframe that will contain your phone/calling UI.  # noqa: E501

        :return: The width of this SettingsPatchRequest.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this SettingsPatchRequest.

        The target width of the iframe that will contain your phone/calling UI.  # noqa: E501

        :param width: The width of this SettingsPatchRequest.  # noqa: E501
        :type width: int
        """

        self._width = width

    @property
    def uses_calling_window(self):
        """Gets the uses_calling_window of this SettingsPatchRequest.  # noqa: E501

        When false, this indicates that your calling app does not require the use of the separate calling window to hold the call connection.   # noqa: E501

        :return: The uses_calling_window of this SettingsPatchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._uses_calling_window

    @uses_calling_window.setter
    def uses_calling_window(self, uses_calling_window):
        """Sets the uses_calling_window of this SettingsPatchRequest.

        When false, this indicates that your calling app does not require the use of the separate calling window to hold the call connection.   # noqa: E501

        :param uses_calling_window: The uses_calling_window of this SettingsPatchRequest.  # noqa: E501
        :type uses_calling_window: bool
        """

        self._uses_calling_window = uses_calling_window

    @property
    def supports_inbound_calling(self):
        """Gets the supports_inbound_calling of this SettingsPatchRequest.  # noqa: E501

        When true, this indicates that your calling app supports inbound calling within HubSpot.  # noqa: E501

        :return: The supports_inbound_calling of this SettingsPatchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._supports_inbound_calling

    @supports_inbound_calling.setter
    def supports_inbound_calling(self, supports_inbound_calling):
        """Sets the supports_inbound_calling of this SettingsPatchRequest.

        When true, this indicates that your calling app supports inbound calling within HubSpot.  # noqa: E501

        :param supports_inbound_calling: The supports_inbound_calling of this SettingsPatchRequest.  # noqa: E501
        :type supports_inbound_calling: bool
        """

        self._supports_inbound_calling = supports_inbound_calling

    @property
    def url(self):
        """Gets the url of this SettingsPatchRequest.  # noqa: E501

        The URL to your phone/calling UI, built with the [Calling SDK](#).  # noqa: E501

        :return: The url of this SettingsPatchRequest.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this SettingsPatchRequest.

        The URL to your phone/calling UI, built with the [Calling SDK](#).  # noqa: E501

        :param url: The url of this SettingsPatchRequest.  # noqa: E501
        :type url: str
        """

        self._url = url

    @property
    def height(self):
        """Gets the height of this SettingsPatchRequest.  # noqa: E501

        The target height of the iframe that will contain your phone/calling UI.  # noqa: E501

        :return: The height of this SettingsPatchRequest.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this SettingsPatchRequest.

        The target height of the iframe that will contain your phone/calling UI.  # noqa: E501

        :param height: The height of this SettingsPatchRequest.  # noqa: E501
        :type height: int
        """

        self._height = height

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SettingsPatchRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SettingsPatchRequest):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.marketing.events.api.add_event_attendees_api import AddEventAttendeesApi
from hubspot.marketing.events.api.basic_api import BasicApi
from hubspot.marketing.events.api.batch_api import BatchApi
from hubspot.marketing.events.api.change_property_api import ChangePropertyApi
from hubspot.marketing.events.api.identifiers_api import IdentifiersApi
from hubspot.marketing.events.api.list_associations_api import ListAssociationsApi
from hubspot.marketing.events.api.retrieve_participant_state_api import RetrieveParticipantStateApi
from hubspot.marketing.events.api.settings_api import SettingsApi
from hubspot.marketing.events.api.subscriber_state_changes_api import SubscriberStateChangesApi



# coding: utf-8

"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.marketing.events.api_client import ApiClient
from hubspot.marketing.events.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class AddEventAttendeesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def record_by_contact_emails(self, external_event_id, subscriber_state, batch_input_marketing_event_email_subscriber, **kwargs):  # noqa: E501
        """Record Participants by Email with Marketing Event External Ids  # noqa: E501

        Records the participation of multiple HubSpot contacts in a Marketing Event using their email addresses.  If a contact does not exist, it will be automatically created. The contactProperties field is used exclusively for creating new contacts and will not update properties of existing contacts.  Additional Functionality: - Adds a timeline event to the contacts.  Allowed Properties: For the state \"attend\": - joinedAt - leftAt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.record_by_contact_emails(external_event_id, subscriber_state, batch_input_marketing_event_email_subscriber, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param subscriber_state: The new subscriber state for the HubSpot contacts and the specified marketing event. For example: 'register', 'attend' or 'cancel'. (required)
        :type subscriber_state: str
        :param batch_input_marketing_event_email_subscriber: (required)
        :type batch_input_marketing_event_email_subscriber: BatchInputMarketingEventEmailSubscriber
        :param external_account_id: The accountId that is associated with this marketing event in the external event application
        :type external_account_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseSubscriberEmailResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.record_by_contact_emails_with_http_info(external_event_id, subscriber_state, batch_input_marketing_event_email_subscriber, **kwargs)  # noqa: E501

    def record_by_contact_emails_with_http_info(self, external_event_id, subscriber_state, batch_input_marketing_event_email_subscriber, **kwargs):  # noqa: E501
        """Record Participants by Email with Marketing Event External Ids  # noqa: E501

        Records the participation of multiple HubSpot contacts in a Marketing Event using their email addresses.  If a contact does not exist, it will be automatically created. The contactProperties field is used exclusively for creating new contacts and will not update properties of existing contacts.  Additional Functionality: - Adds a timeline event to the contacts.  Allowed Properties: For the state \"attend\": - joinedAt - leftAt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.record_by_contact_emails_with_http_info(external_event_id, subscriber_state, batch_input_marketing_event_email_subscriber, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param subscriber_state: The new subscriber state for the HubSpot contacts and the specified marketing event. For example: 'register', 'attend' or 'cancel'. (required)
        :type subscriber_state: str
        :param batch_input_marketing_event_email_subscriber: (required)
        :type batch_input_marketing_event_email_subscriber: BatchInputMarketingEventEmailSubscriber
        :param external_account_id: The accountId that is associated with this marketing event in the external event application
        :type external_account_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseSubscriberEmailResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["external_event_id", "subscriber_state", "batch_input_marketing_event_email_subscriber", "external_account_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method record_by_contact_emails" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'external_event_id' is set
        if self.api_client.client_side_validation and local_var_params.get("external_event_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_event_id` when calling `record_by_contact_emails`")  # noqa: E501
        # verify the required parameter 'subscriber_state' is set
        if self.api_client.client_side_validation and local_var_params.get("subscriber_state") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `subscriber_state` when calling `record_by_contact_emails`")  # noqa: E501
        # verify the required parameter 'batch_input_marketing_event_email_subscriber' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_marketing_event_email_subscriber") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_marketing_event_email_subscriber` when calling `record_by_contact_emails`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "external_event_id" in local_var_params:
            path_params["externalEventId"] = local_var_params["external_event_id"]  # noqa: E501
        if "subscriber_state" in local_var_params:
            path_params["subscriberState"] = local_var_params["subscriber_state"]  # noqa: E501

        query_params = []
        if local_var_params.get("external_account_id") is not None:  # noqa: E501
            query_params.append(("externalAccountId", local_var_params["external_account_id"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_marketing_event_email_subscriber" in local_var_params:
            body_params = local_var_params["batch_input_marketing_event_email_subscriber"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseSubscriberEmailResponse",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/attendance/{externalEventId}/{subscriberState}/email-create",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def record_by_contact_id(self, object_id, subscriber_state, batch_input_marketing_event_subscriber, **kwargs):  # noqa: E501
        """Record Participants by ContactId with Marketing Event Object Id  # noqa: E501

        Records the participation of multiple HubSpot contacts in a Marketing Event using their HubSpot contact IDs.  Additional Functionality: - Adds a timeline event to the contacts.  Allowed Properties: For the state \"attend\": - joinedAt - leftAt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.record_by_contact_id(object_id, subscriber_state, batch_input_marketing_event_subscriber, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal id of the marketing event in HubSpot (required)
        :type object_id: str
        :param subscriber_state: The attendance state value. It may be 'register', 'attend' or 'cancel' (required)
        :type subscriber_state: str
        :param batch_input_marketing_event_subscriber: (required)
        :type batch_input_marketing_event_subscriber: BatchInputMarketingEventSubscriber
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseSubscriberVidResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.record_by_contact_id_with_http_info(object_id, subscriber_state, batch_input_marketing_event_subscriber, **kwargs)  # noqa: E501

    def record_by_contact_id_with_http_info(self, object_id, subscriber_state, batch_input_marketing_event_subscriber, **kwargs):  # noqa: E501
        """Record Participants by ContactId with Marketing Event Object Id  # noqa: E501

        Records the participation of multiple HubSpot contacts in a Marketing Event using their HubSpot contact IDs.  Additional Functionality: - Adds a timeline event to the contacts.  Allowed Properties: For the state \"attend\": - joinedAt - leftAt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.record_by_contact_id_with_http_info(object_id, subscriber_state, batch_input_marketing_event_subscriber, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal id of the marketing event in HubSpot (required)
        :type object_id: str
        :param subscriber_state: The attendance state value. It may be 'register', 'attend' or 'cancel' (required)
        :type subscriber_state: str
        :param batch_input_marketing_event_subscriber: (required)
        :type batch_input_marketing_event_subscriber: BatchInputMarketingEventSubscriber
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseSubscriberVidResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_id", "subscriber_state", "batch_input_marketing_event_subscriber"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method record_by_contact_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_id` when calling `record_by_contact_id`")  # noqa: E501
        # verify the required parameter 'subscriber_state' is set
        if self.api_client.client_side_validation and local_var_params.get("subscriber_state") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `subscriber_state` when calling `record_by_contact_id`")  # noqa: E501
        # verify the required parameter 'batch_input_marketing_event_subscriber' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_marketing_event_subscriber") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_marketing_event_subscriber` when calling `record_by_contact_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_id" in local_var_params:
            path_params["objectId"] = local_var_params["object_id"]  # noqa: E501
        if "subscriber_state" in local_var_params:
            path_params["subscriberState"] = local_var_params["subscriber_state"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_marketing_event_subscriber" in local_var_params:
            body_params = local_var_params["batch_input_marketing_event_subscriber"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseSubscriberVidResponse",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/{objectId}/attendance/{subscriberState}/create",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def record_by_contact_ids(self, external_event_id, subscriber_state, batch_input_marketing_event_subscriber, **kwargs):  # noqa: E501
        """Record Participants by ContactId with Marketing Event External Ids  # noqa: E501

        Records the participation of multiple HubSpot contacts in a Marketing Event using their HubSpot contact IDs.  Additional Functionality: - Adds a timeline event to the contacts.  Allowed Properties: For the state \"attend\": - joinedAt - leftAt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.record_by_contact_ids(external_event_id, subscriber_state, batch_input_marketing_event_subscriber, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param subscriber_state: The new subscriber state for the HubSpot contacts and the specified marketing event. For example: 'register', 'attend' or 'cancel'. (required)
        :type subscriber_state: str
        :param batch_input_marketing_event_subscriber: (required)
        :type batch_input_marketing_event_subscriber: BatchInputMarketingEventSubscriber
        :param external_account_id: The accountId that is associated with this marketing event in the external event application
        :type external_account_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseSubscriberVidResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.record_by_contact_ids_with_http_info(external_event_id, subscriber_state, batch_input_marketing_event_subscriber, **kwargs)  # noqa: E501

    def record_by_contact_ids_with_http_info(self, external_event_id, subscriber_state, batch_input_marketing_event_subscriber, **kwargs):  # noqa: E501
        """Record Participants by ContactId with Marketing Event External Ids  # noqa: E501

        Records the participation of multiple HubSpot contacts in a Marketing Event using their HubSpot contact IDs.  Additional Functionality: - Adds a timeline event to the contacts.  Allowed Properties: For the state \"attend\": - joinedAt - leftAt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.record_by_contact_ids_with_http_info(external_event_id, subscriber_state, batch_input_marketing_event_subscriber, async_req=True)
        >>> result = thread.get()

        :param external_event_id: The id of the marketing event in the external event application (required)
        :type external_event_id: str
        :param subscriber_state: The new subscriber state for the HubSpot contacts and the specified marketing event. For example: 'register', 'attend' or 'cancel'. (required)
        :type subscriber_state: str
        :param batch_input_marketing_event_subscriber: (required)
        :type batch_input_marketing_event_subscriber: BatchInputMarketingEventSubscriber
        :param external_account_id: The accountId that is associated with this marketing event in the external event application
        :type external_account_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseSubscriberVidResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["external_event_id", "subscriber_state", "batch_input_marketing_event_subscriber", "external_account_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method record_by_contact_ids" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'external_event_id' is set
        if self.api_client.client_side_validation and local_var_params.get("external_event_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_event_id` when calling `record_by_contact_ids`")  # noqa: E501
        # verify the required parameter 'subscriber_state' is set
        if self.api_client.client_side_validation and local_var_params.get("subscriber_state") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `subscriber_state` when calling `record_by_contact_ids`")  # noqa: E501
        # verify the required parameter 'batch_input_marketing_event_subscriber' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_marketing_event_subscriber") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_marketing_event_subscriber` when calling `record_by_contact_ids`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "external_event_id" in local_var_params:
            path_params["externalEventId"] = local_var_params["external_event_id"]  # noqa: E501
        if "subscriber_state" in local_var_params:
            path_params["subscriberState"] = local_var_params["subscriber_state"]  # noqa: E501

        query_params = []
        if local_var_params.get("external_account_id") is not None:  # noqa: E501
            query_params.append(("externalAccountId", local_var_params["external_account_id"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_marketing_event_subscriber" in local_var_params:
            body_params = local_var_params["batch_input_marketing_event_subscriber"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseSubscriberVidResponse",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/attendance/{externalEventId}/{subscriberState}/create",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def record_by_email(self, object_id, subscriber_state, batch_input_marketing_event_email_subscriber, **kwargs):  # noqa: E501
        """Record Participants by Email with Marketing Event Object Id  # noqa: E501

        Records the participation of multiple HubSpot contacts in a Marketing Event using their email addresses.  If a contact does not exist, it will be automatically created. The contactProperties field is used exclusively for creating new contacts and will not update properties of existing contacts.  Additional Functionality: - Adds a timeline event to the contacts.  Allowed Properties: For the state \"attend\": - joinedAt - leftAt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.record_by_email(object_id, subscriber_state, batch_input_marketing_event_email_subscriber, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal ID of the marketing event in HubSpot (required)
        :type object_id: str
        :param subscriber_state: The attendance state value. It may be 'register', 'attend' or 'cancel' (required)
        :type subscriber_state: str
        :param batch_input_marketing_event_email_subscriber: (required)
        :type batch_input_marketing_event_email_subscriber: BatchInputMarketingEventEmailSubscriber
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseSubscriberEmailResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.record_by_email_with_http_info(object_id, subscriber_state, batch_input_marketing_event_email_subscriber, **kwargs)  # noqa: E501

    def record_by_email_with_http_info(self, object_id, subscriber_state, batch_input_marketing_event_email_subscriber, **kwargs):  # noqa: E501
        """Record Participants by Email with Marketing Event Object Id  # noqa: E501

        Records the participation of multiple HubSpot contacts in a Marketing Event using their email addresses.  If a contact does not exist, it will be automatically created. The contactProperties field is used exclusively for creating new contacts and will not update properties of existing contacts.  Additional Functionality: - Adds a timeline event to the contacts.  Allowed Properties: For the state \"attend\": - joinedAt - leftAt  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.record_by_email_with_http_info(object_id, subscriber_state, batch_input_marketing_event_email_subscriber, async_req=True)
        >>> result = thread.get()

        :param object_id: The internal ID of the marketing event in HubSpot (required)
        :type object_id: str
        :param subscriber_state: The attendance state value. It may be 'register', 'attend' or 'cancel' (required)
        :type subscriber_state: str
        :param batch_input_marketing_event_email_subscriber: (required)
        :type batch_input_marketing_event_email_subscriber: BatchInputMarketingEventEmailSubscriber
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseSubscriberEmailResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_id", "subscriber_state", "batch_input_marketing_event_email_subscriber"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method record_by_email" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_id` when calling `record_by_email`")  # noqa: E501
        # verify the required parameter 'subscriber_state' is set
        if self.api_client.client_side_validation and local_var_params.get("subscriber_state") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `subscriber_state` when calling `record_by_email`")  # noqa: E501
        # verify the required parameter 'batch_input_marketing_event_email_subscriber' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_marketing_event_email_subscriber") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_marketing_event_email_subscriber` when calling `record_by_email`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_id" in local_var_params:
            path_params["objectId"] = local_var_params["object_id"]  # noqa: E501
        if "subscriber_state" in local_var_params:
            path_params["subscriberState"] = local_var_params["subscriber_state"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_marketing_event_email_subscriber" in local_var_params:
            body_params = local_var_params["batch_input_marketing_event_email_subscriber"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseSubscriberEmailResponse",
        }

        return self.api_client.call_api(
            "/marketing/v3/marketing-events/{objectId}/attendance/{subscriberState}/email-create",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.marketing.transactional.api.public_smtp_tokens_api import PublicSMTPTokensApi
from hubspot.marketing.transactional.api.single_send_api import SingleSendApi



# flake8: noqa

# import apis into api package
from hubspot.conversations.custom_channels.api.channel_account_staging_tokens_api import ChannelAccountStagingTokensApi
from hubspot.conversations.custom_channels.api.channel_accounts_api import ChannelAccountsApi
from hubspot.conversations.custom_channels.api.channels_api import ChannelsApi
from hubspot.conversations.custom_channels.api.messages_api import MessagesApi




# coding: utf-8

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.files.configuration import Configuration


class ImportFromUrlInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "folder_path": "str",
        "access": "str",
        "duplicate_validation_scope": "str",
        "name": "str",
        "duplicate_validation_strategy": "str",
        "ttl": "str",
        "overwrite": "bool",
        "expires_at": "datetime",
        "url": "str",
        "folder_id": "str",
    }

    attribute_map = {
        "folder_path": "folderPath",
        "access": "access",
        "duplicate_validation_scope": "duplicateValidationScope",
        "name": "name",
        "duplicate_validation_strategy": "duplicateValidationStrategy",
        "ttl": "ttl",
        "overwrite": "overwrite",
        "expires_at": "expiresAt",
        "url": "url",
        "folder_id": "folderId",
    }

    def __init__(
        self,
        folder_path=None,
        access=None,
        duplicate_validation_scope=None,
        name=None,
        duplicate_validation_strategy=None,
        ttl=None,
        overwrite=None,
        expires_at=None,
        url=None,
        folder_id=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ImportFromUrlInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._folder_path = None
        self._access = None
        self._duplicate_validation_scope = None
        self._name = None
        self._duplicate_validation_strategy = None
        self._ttl = None
        self._overwrite = None
        self._expires_at = None
        self._url = None
        self._folder_id = None
        self.discriminator = None

        if folder_path is not None:
            self.folder_path = folder_path
        self.access = access
        if duplicate_validation_scope is not None:
            self.duplicate_validation_scope = duplicate_validation_scope
        if name is not None:
            self.name = name
        if duplicate_validation_strategy is not None:
            self.duplicate_validation_strategy = duplicate_validation_strategy
        if ttl is not None:
            self.ttl = ttl
        if overwrite is not None:
            self.overwrite = overwrite
        if expires_at is not None:
            self.expires_at = expires_at
        self.url = url
        if folder_id is not None:
            self.folder_id = folder_id

    @property
    def folder_path(self):
        """Gets the folder_path of this ImportFromUrlInput.  # noqa: E501

        One of folderPath or folderId is required. Destination folder path for the uploaded file. If the folder path does not exist, there will be an attempt to create the folder path.  # noqa: E501

        :return: The folder_path of this ImportFromUrlInput.  # noqa: E501
        :rtype: str
        """
        return self._folder_path

    @folder_path.setter
    def folder_path(self, folder_path):
        """Sets the folder_path of this ImportFromUrlInput.

        One of folderPath or folderId is required. Destination folder path for the uploaded file. If the folder path does not exist, there will be an attempt to create the folder path.  # noqa: E501

        :param folder_path: The folder_path of this ImportFromUrlInput.  # noqa: E501
        :type folder_path: str
        """

        self._folder_path = folder_path

    @property
    def access(self):
        """Gets the access of this ImportFromUrlInput.  # noqa: E501

        PUBLIC_INDEXABLE: File is publicly accessible by anyone who has the URL. Search engines can index the file. PUBLIC_NOT_INDEXABLE: File is publicly accessible by anyone who has the URL. Search engines *can't* index the file. PRIVATE: File is NOT publicly accessible. Requires a signed URL to see content. Search engines *can't* index the file.   # noqa: E501

        :return: The access of this ImportFromUrlInput.  # noqa: E501
        :rtype: str
        """
        return self._access

    @access.setter
    def access(self, access):
        """Sets the access of this ImportFromUrlInput.

        PUBLIC_INDEXABLE: File is publicly accessible by anyone who has the URL. Search engines can index the file. PUBLIC_NOT_INDEXABLE: File is publicly accessible by anyone who has the URL. Search engines *can't* index the file. PRIVATE: File is NOT publicly accessible. Requires a signed URL to see content. Search engines *can't* index the file.   # noqa: E501

        :param access: The access of this ImportFromUrlInput.  # noqa: E501
        :type access: str
        """
        if self.local_vars_configuration.client_side_validation and access is None:  # noqa: E501
            raise ValueError("Invalid value for `access`, must not be `None`")  # noqa: E501
        allowed_values = ["PUBLIC_INDEXABLE", "PUBLIC_NOT_INDEXABLE", "HIDDEN_INDEXABLE", "HIDDEN_NOT_INDEXABLE", "HIDDEN_PRIVATE", "PRIVATE", "HIDDEN_SENSITIVE", "SENSITIVE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and access not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `access` ({0}), must be one of {1}".format(access, allowed_values))  # noqa: E501

        self._access = access

    @property
    def duplicate_validation_scope(self):
        """Gets the duplicate_validation_scope of this ImportFromUrlInput.  # noqa: E501

        ENTIRE_PORTAL: Look for a duplicate file in the entire account. EXACT_FOLDER: Look for a duplicate file in the provided folder.   # noqa: E501

        :return: The duplicate_validation_scope of this ImportFromUrlInput.  # noqa: E501
        :rtype: str
        """
        return self._duplicate_validation_scope

    @duplicate_validation_scope.setter
    def duplicate_validation_scope(self, duplicate_validation_scope):
        """Sets the duplicate_validation_scope of this ImportFromUrlInput.

        ENTIRE_PORTAL: Look for a duplicate file in the entire account. EXACT_FOLDER: Look for a duplicate file in the provided folder.   # noqa: E501

        :param duplicate_validation_scope: The duplicate_validation_scope of this ImportFromUrlInput.  # noqa: E501
        :type duplicate_validation_scope: str
        """
        allowed_values = ["ENTIRE_PORTAL", "EXACT_FOLDER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and duplicate_validation_scope not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `duplicate_validation_scope` ({0}), must be one of {1}".format(duplicate_validation_scope, allowed_values))  # noqa: E501

        self._duplicate_validation_scope = duplicate_validation_scope

    @property
    def name(self):
        """Gets the name of this ImportFromUrlInput.  # noqa: E501

        Name to give the resulting file in the file manager.  # noqa: E501

        :return: The name of this ImportFromUrlInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ImportFromUrlInput.

        Name to give the resulting file in the file manager.  # noqa: E501

        :param name: The name of this ImportFromUrlInput.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def duplicate_validation_strategy(self):
        """Gets the duplicate_validation_strategy of this ImportFromUrlInput.  # noqa: E501

        NONE: Do not run any duplicate validation. REJECT: Reject the upload if a duplicate is found. RETURN_EXISTING: If a duplicate file is found, do not upload a new file and return the found duplicate instead.   # noqa: E501

        :return: The duplicate_validation_strategy of this ImportFromUrlInput.  # noqa: E501
        :rtype: str
        """
        return self._duplicate_validation_strategy

    @duplicate_validation_strategy.setter
    def duplicate_validation_strategy(self, duplicate_validation_strategy):
        """Sets the duplicate_validation_strategy of this ImportFromUrlInput.

        NONE: Do not run any duplicate validation. REJECT: Reject the upload if a duplicate is found. RETURN_EXISTING: If a duplicate file is found, do not upload a new file and return the found duplicate instead.   # noqa: E501

        :param duplicate_validation_strategy: The duplicate_validation_strategy of this ImportFromUrlInput.  # noqa: E501
        :type duplicate_validation_strategy: str
        """
        allowed_values = ["NONE", "REJECT", "RETURN_EXISTING"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and duplicate_validation_strategy not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `duplicate_validation_strategy` ({0}), must be one of {1}".format(duplicate_validation_strategy, allowed_values))  # noqa: E501

        self._duplicate_validation_strategy = duplicate_validation_strategy

    @property
    def ttl(self):
        """Gets the ttl of this ImportFromUrlInput.  # noqa: E501

        Time to live. If specified the file will be deleted after the given time frame. If left unset, the file will exist indefinitely  # noqa: E501

        :return: The ttl of this ImportFromUrlInput.  # noqa: E501
        :rtype: str
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this ImportFromUrlInput.

        Time to live. If specified the file will be deleted after the given time frame. If left unset, the file will exist indefinitely  # noqa: E501

        :param ttl: The ttl of this ImportFromUrlInput.  # noqa: E501
        :type ttl: str
        """

        self._ttl = ttl

    @property
    def overwrite(self):
        """Gets the overwrite of this ImportFromUrlInput.  # noqa: E501

        If true, will overwrite existing file if one with the same name and extension exists in the given folder. The overwritten file will be deleted and the uploaded file will take its place with a new ID. If unset or set as false, the new file's name will be updated to prevent colliding with existing file if one exists with the same path, name, and extension  # noqa: E501

        :return: The overwrite of this ImportFromUrlInput.  # noqa: E501
        :rtype: bool
        """
        return self._overwrite

    @overwrite.setter
    def overwrite(self, overwrite):
        """Sets the overwrite of this ImportFromUrlInput.

        If true, will overwrite existing file if one with the same name and extension exists in the given folder. The overwritten file will be deleted and the uploaded file will take its place with a new ID. If unset or set as false, the new file's name will be updated to prevent colliding with existing file if one exists with the same path, name, and extension  # noqa: E501

        :param overwrite: The overwrite of this ImportFromUrlInput.  # noqa: E501
        :type overwrite: bool
        """

        self._overwrite = overwrite

    @property
    def expires_at(self):
        """Gets the expires_at of this ImportFromUrlInput.  # noqa: E501


        :return: The expires_at of this ImportFromUrlInput.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this ImportFromUrlInput.


        :param expires_at: The expires_at of this ImportFromUrlInput.  # noqa: E501
        :type expires_at: datetime
        """

        self._expires_at = expires_at

    @property
    def url(self):
        """Gets the url of this ImportFromUrlInput.  # noqa: E501

        URL to download the new file from.  # noqa: E501

        :return: The url of this ImportFromUrlInput.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ImportFromUrlInput.

        URL to download the new file from.  # noqa: E501

        :param url: The url of this ImportFromUrlInput.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def folder_id(self):
        """Gets the folder_id of this ImportFromUrlInput.  # noqa: E501

        One of folderId or folderPath is required. Destination folderId for the uploaded file.  # noqa: E501

        :return: The folder_id of this ImportFromUrlInput.  # noqa: E501
        :rtype: str
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """Sets the folder_id of this ImportFromUrlInput.

        One of folderId or folderPath is required. Destination folderId for the uploaded file.  # noqa: E501

        :param folder_id: The folder_id of this ImportFromUrlInput.  # noqa: E501
        :type folder_id: str
        """

        self._folder_id = folder_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportFromUrlInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImportFromUrlInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CRM Exports

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.exports.configuration import Configuration


class PublicExportViewRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "export_type": "str",
        "format": "str",
        "export_name": "str",
        "object_properties": "list[str]",
        "associated_object_type": "str",
        "object_type": "str",
        "language": "str",
        "export_internal_values_options": "list[str]",
        "override_associated_objects_per_definition_per_row_limit": "bool",
        "public_crm_search_request": "PublicCrmSearchRequest",
    }

    attribute_map = {
        "export_type": "exportType",
        "format": "format",
        "export_name": "exportName",
        "object_properties": "objectProperties",
        "associated_object_type": "associatedObjectType",
        "object_type": "objectType",
        "language": "language",
        "export_internal_values_options": "exportInternalValuesOptions",
        "override_associated_objects_per_definition_per_row_limit": "overrideAssociatedObjectsPerDefinitionPerRowLimit",
        "public_crm_search_request": "publicCrmSearchRequest",
    }

    def __init__(
        self,
        export_type="VIEW",
        format=None,
        export_name=None,
        object_properties=None,
        associated_object_type=None,
        object_type=None,
        language=None,
        export_internal_values_options=None,
        override_associated_objects_per_definition_per_row_limit=None,
        public_crm_search_request=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicExportViewRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._export_type = None
        self._format = None
        self._export_name = None
        self._object_properties = None
        self._associated_object_type = None
        self._object_type = None
        self._language = None
        self._export_internal_values_options = None
        self._override_associated_objects_per_definition_per_row_limit = None
        self._public_crm_search_request = None
        self.discriminator = None

        self.export_type = export_type
        self.format = format
        self.export_name = export_name
        self.object_properties = object_properties
        if associated_object_type is not None:
            self.associated_object_type = associated_object_type
        self.object_type = object_type
        self.language = language
        self.export_internal_values_options = export_internal_values_options
        self.override_associated_objects_per_definition_per_row_limit = override_associated_objects_per_definition_per_row_limit
        if public_crm_search_request is not None:
            self.public_crm_search_request = public_crm_search_request

    @property
    def export_type(self):
        """Gets the export_type of this PublicExportViewRequest.  # noqa: E501


        :return: The export_type of this PublicExportViewRequest.  # noqa: E501
        :rtype: str
        """
        return self._export_type

    @export_type.setter
    def export_type(self, export_type):
        """Sets the export_type of this PublicExportViewRequest.


        :param export_type: The export_type of this PublicExportViewRequest.  # noqa: E501
        :type export_type: str
        """
        if self.local_vars_configuration.client_side_validation and export_type is None:  # noqa: E501
            raise ValueError("Invalid value for `export_type`, must not be `None`")  # noqa: E501
        allowed_values = ["VIEW"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and export_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `export_type` ({0}), must be one of {1}".format(export_type, allowed_values))  # noqa: E501

        self._export_type = export_type

    @property
    def format(self):
        """Gets the format of this PublicExportViewRequest.  # noqa: E501


        :return: The format of this PublicExportViewRequest.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this PublicExportViewRequest.


        :param format: The format of this PublicExportViewRequest.  # noqa: E501
        :type format: str
        """
        if self.local_vars_configuration.client_side_validation and format is None:  # noqa: E501
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501
        allowed_values = ["XLS", "XLSX", "CSV"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and format not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `format` ({0}), must be one of {1}".format(format, allowed_values))  # noqa: E501

        self._format = format

    @property
    def export_name(self):
        """Gets the export_name of this PublicExportViewRequest.  # noqa: E501


        :return: The export_name of this PublicExportViewRequest.  # noqa: E501
        :rtype: str
        """
        return self._export_name

    @export_name.setter
    def export_name(self, export_name):
        """Sets the export_name of this PublicExportViewRequest.


        :param export_name: The export_name of this PublicExportViewRequest.  # noqa: E501
        :type export_name: str
        """
        if self.local_vars_configuration.client_side_validation and export_name is None:  # noqa: E501
            raise ValueError("Invalid value for `export_name`, must not be `None`")  # noqa: E501

        self._export_name = export_name

    @property
    def object_properties(self):
        """Gets the object_properties of this PublicExportViewRequest.  # noqa: E501


        :return: The object_properties of this PublicExportViewRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._object_properties

    @object_properties.setter
    def object_properties(self, object_properties):
        """Sets the object_properties of this PublicExportViewRequest.


        :param object_properties: The object_properties of this PublicExportViewRequest.  # noqa: E501
        :type object_properties: list[str]
        """
        if self.local_vars_configuration.client_side_validation and object_properties is None:  # noqa: E501
            raise ValueError("Invalid value for `object_properties`, must not be `None`")  # noqa: E501

        self._object_properties = object_properties

    @property
    def associated_object_type(self):
        """Gets the associated_object_type of this PublicExportViewRequest.  # noqa: E501


        :return: The associated_object_type of this PublicExportViewRequest.  # noqa: E501
        :rtype: str
        """
        return self._associated_object_type

    @associated_object_type.setter
    def associated_object_type(self, associated_object_type):
        """Sets the associated_object_type of this PublicExportViewRequest.


        :param associated_object_type: The associated_object_type of this PublicExportViewRequest.  # noqa: E501
        :type associated_object_type: str
        """

        self._associated_object_type = associated_object_type

    @property
    def object_type(self):
        """Gets the object_type of this PublicExportViewRequest.  # noqa: E501


        :return: The object_type of this PublicExportViewRequest.  # noqa: E501
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this PublicExportViewRequest.


        :param object_type: The object_type of this PublicExportViewRequest.  # noqa: E501
        :type object_type: str
        """
        if self.local_vars_configuration.client_side_validation and object_type is None:  # noqa: E501
            raise ValueError("Invalid value for `object_type`, must not be `None`")  # noqa: E501

        self._object_type = object_type

    @property
    def language(self):
        """Gets the language of this PublicExportViewRequest.  # noqa: E501


        :return: The language of this PublicExportViewRequest.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this PublicExportViewRequest.


        :param language: The language of this PublicExportViewRequest.  # noqa: E501
        :type language: str
        """
        if self.local_vars_configuration.client_side_validation and language is None:  # noqa: E501
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501
        allowed_values = ["EN", "DE", "ES", "FR", "JA", "NL", "PT_BR", "IT", "PL", "SV", "FI", "ZH_TW", "DA_DK", "NO"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and language not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `language` ({0}), must be one of {1}".format(language, allowed_values))  # noqa: E501

        self._language = language

    @property
    def export_internal_values_options(self):
        """Gets the export_internal_values_options of this PublicExportViewRequest.  # noqa: E501


        :return: The export_internal_values_options of this PublicExportViewRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._export_internal_values_options

    @export_internal_values_options.setter
    def export_internal_values_options(self, export_internal_values_options):
        """Sets the export_internal_values_options of this PublicExportViewRequest.


        :param export_internal_values_options: The export_internal_values_options of this PublicExportViewRequest.  # noqa: E501
        :type export_internal_values_options: list[str]
        """
        if self.local_vars_configuration.client_side_validation and export_internal_values_options is None:  # noqa: E501
            raise ValueError("Invalid value for `export_internal_values_options`, must not be `None`")  # noqa: E501
        allowed_values = ["NAMES", "VALUES"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and not set(export_internal_values_options).issubset(set(allowed_values)):  # noqa: E501
            raise ValueError(
                "Invalid values for `export_internal_values_options` [{0}], must be a subset of [{1}]".format(  # noqa: E501
                    ", ".join(map(str, set(export_internal_values_options) - set(allowed_values))), ", ".join(map(str, allowed_values))  # noqa: E501
                )
            )

        self._export_internal_values_options = export_internal_values_options

    @property
    def override_associated_objects_per_definition_per_row_limit(self):
        """Gets the override_associated_objects_per_definition_per_row_limit of this PublicExportViewRequest.  # noqa: E501


        :return: The override_associated_objects_per_definition_per_row_limit of this PublicExportViewRequest.  # noqa: E501
        :rtype: bool
        """
        return self._override_associated_objects_per_definition_per_row_limit

    @override_associated_objects_per_definition_per_row_limit.setter
    def override_associated_objects_per_definition_per_row_limit(self, override_associated_objects_per_definition_per_row_limit):
        """Sets the override_associated_objects_per_definition_per_row_limit of this PublicExportViewRequest.


        :param override_associated_objects_per_definition_per_row_limit: The override_associated_objects_per_definition_per_row_limit of this PublicExportViewRequest.  # noqa: E501
        :type override_associated_objects_per_definition_per_row_limit: bool
        """
        if self.local_vars_configuration.client_side_validation and override_associated_objects_per_definition_per_row_limit is None:  # noqa: E501
            raise ValueError("Invalid value for `override_associated_objects_per_definition_per_row_limit`, must not be `None`")  # noqa: E501

        self._override_associated_objects_per_definition_per_row_limit = override_associated_objects_per_definition_per_row_limit

    @property
    def public_crm_search_request(self):
        """Gets the public_crm_search_request of this PublicExportViewRequest.  # noqa: E501


        :return: The public_crm_search_request of this PublicExportViewRequest.  # noqa: E501
        :rtype: PublicCrmSearchRequest
        """
        return self._public_crm_search_request

    @public_crm_search_request.setter
    def public_crm_search_request(self, public_crm_search_request):
        """Sets the public_crm_search_request of this PublicExportViewRequest.


        :param public_crm_search_request: The public_crm_search_request of this PublicExportViewRequest.  # noqa: E501
        :type public_crm_search_request: PublicCrmSearchRequest
        """

        self._public_crm_search_request = public_crm_search_request

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicExportViewRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicExportViewRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class PublicFontStyle(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"size": "int", "color": "str", "underline": "bool", "bold": "bool", "italic": "bool", "font": "str"}

    attribute_map = {"size": "size", "color": "color", "underline": "underline", "bold": "bold", "italic": "italic", "font": "font"}

    def __init__(self, size=None, color=None, underline=None, bold=None, italic=None, font=None, local_vars_configuration=None):  # noqa: E501
        """PublicFontStyle - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._size = None
        self._color = None
        self._underline = None
        self._bold = None
        self._italic = None
        self._font = None
        self.discriminator = None

        if size is not None:
            self.size = size
        if color is not None:
            self.color = color
        if underline is not None:
            self.underline = underline
        if bold is not None:
            self.bold = bold
        if italic is not None:
            self.italic = italic
        if font is not None:
            self.font = font

    @property
    def size(self):
        """Gets the size of this PublicFontStyle.  # noqa: E501


        :return: The size of this PublicFontStyle.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this PublicFontStyle.


        :param size: The size of this PublicFontStyle.  # noqa: E501
        :type size: int
        """

        self._size = size

    @property
    def color(self):
        """Gets the color of this PublicFontStyle.  # noqa: E501


        :return: The color of this PublicFontStyle.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this PublicFontStyle.


        :param color: The color of this PublicFontStyle.  # noqa: E501
        :type color: str
        """

        self._color = color

    @property
    def underline(self):
        """Gets the underline of this PublicFontStyle.  # noqa: E501


        :return: The underline of this PublicFontStyle.  # noqa: E501
        :rtype: bool
        """
        return self._underline

    @underline.setter
    def underline(self, underline):
        """Sets the underline of this PublicFontStyle.


        :param underline: The underline of this PublicFontStyle.  # noqa: E501
        :type underline: bool
        """

        self._underline = underline

    @property
    def bold(self):
        """Gets the bold of this PublicFontStyle.  # noqa: E501


        :return: The bold of this PublicFontStyle.  # noqa: E501
        :rtype: bool
        """
        return self._bold

    @bold.setter
    def bold(self, bold):
        """Sets the bold of this PublicFontStyle.


        :param bold: The bold of this PublicFontStyle.  # noqa: E501
        :type bold: bool
        """

        self._bold = bold

    @property
    def italic(self):
        """Gets the italic of this PublicFontStyle.  # noqa: E501


        :return: The italic of this PublicFontStyle.  # noqa: E501
        :rtype: bool
        """
        return self._italic

    @italic.setter
    def italic(self, italic):
        """Sets the italic of this PublicFontStyle.


        :param italic: The italic of this PublicFontStyle.  # noqa: E501
        :type italic: bool
        """

        self._italic = italic

    @property
    def font(self):
        """Gets the font of this PublicFontStyle.  # noqa: E501


        :return: The font of this PublicFontStyle.  # noqa: E501
        :rtype: str
        """
        return self._font

    @font.setter
    def font(self, font):
        """Sets the font of this PublicFontStyle.


        :param font: The font of this PublicFontStyle.  # noqa: E501
        :type font: str
        """

        self._font = font

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicFontStyle):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicFontStyle):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.cms.pages.api.landing_pages_api import LandingPagesApi
from hubspot.cms.pages.api.site_pages_api import SitePagesApi



# coding: utf-8

"""
    Pipelines

    Pipelines represent distinct stages in a workflow, like closing a deal or servicing a support ticket. These endpoints provide access to read and modify pipelines in HubSpot. Pipelines support `deals` and `tickets` object types.  ## Pipeline ID validation  When calling endpoints that take pipelineId as a parameter, that ID must correspond to an existing, un-archived pipeline. Otherwise the request will fail with a `404 Not Found` response.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.pipelines.configuration import Configuration


class PipelineStagePatchInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"archived": "bool", "metadata": "dict[str, str]", "display_order": "int", "label": "str"}

    attribute_map = {"archived": "archived", "metadata": "metadata", "display_order": "displayOrder", "label": "label"}

    def __init__(self, archived=None, metadata=None, display_order=None, label=None, local_vars_configuration=None):  # noqa: E501
        """PipelineStagePatchInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._archived = None
        self._metadata = None
        self._display_order = None
        self._label = None
        self.discriminator = None

        if archived is not None:
            self.archived = archived
        if metadata is not None:
            self.metadata = metadata
        if display_order is not None:
            self.display_order = display_order
        if label is not None:
            self.label = label

    @property
    def archived(self):
        """Gets the archived of this PipelineStagePatchInput.  # noqa: E501

        Whether the pipeline is archived.  # noqa: E501

        :return: The archived of this PipelineStagePatchInput.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this PipelineStagePatchInput.

        Whether the pipeline is archived.  # noqa: E501

        :param archived: The archived of this PipelineStagePatchInput.  # noqa: E501
        :type archived: bool
        """

        self._archived = archived

    @property
    def metadata(self):
        """Gets the metadata of this PipelineStagePatchInput.  # noqa: E501

        A JSON object containing properties that are not present on all object pipelines.  For `deals` pipelines, the `probability` field is required (`{ \"probability\": 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.  For `tickets` pipelines, the `ticketState` field is optional (`{ \"ticketState\": \"OPEN\" }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`.  # noqa: E501

        :return: The metadata of this PipelineStagePatchInput.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this PipelineStagePatchInput.

        A JSON object containing properties that are not present on all object pipelines.  For `deals` pipelines, the `probability` field is required (`{ \"probability\": 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.  For `tickets` pipelines, the `ticketState` field is optional (`{ \"ticketState\": \"OPEN\" }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`.  # noqa: E501

        :param metadata: The metadata of this PipelineStagePatchInput.  # noqa: E501
        :type metadata: dict[str, str]
        """

        self._metadata = metadata

    @property
    def display_order(self):
        """Gets the display_order of this PipelineStagePatchInput.  # noqa: E501

        The order for displaying this pipeline stage. If two pipeline stages have a matching `displayOrder`, they will be sorted alphabetically by label.  # noqa: E501

        :return: The display_order of this PipelineStagePatchInput.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this PipelineStagePatchInput.

        The order for displaying this pipeline stage. If two pipeline stages have a matching `displayOrder`, they will be sorted alphabetically by label.  # noqa: E501

        :param display_order: The display_order of this PipelineStagePatchInput.  # noqa: E501
        :type display_order: int
        """

        self._display_order = display_order

    @property
    def label(self):
        """Gets the label of this PipelineStagePatchInput.  # noqa: E501

        A label used to organize pipeline stages in HubSpot's UI. Each pipeline stage's label must be unique within that pipeline.  # noqa: E501

        :return: The label of this PipelineStagePatchInput.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this PipelineStagePatchInput.

        A label used to organize pipeline stages in HubSpot's UI. Each pipeline stage's label must be unique within that pipeline.  # noqa: E501

        :param label: The label of this PipelineStagePatchInput.  # noqa: E501
        :type label: str
        """

        self._label = label

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PipelineStagePatchInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PipelineStagePatchInput):
            return True

        return self.to_dict() != other.to_dict()



from ..discovery_base import DiscoveryBase

class Discovery(DiscoveryBase):
    @property
    def visitor_identification(self):
        from .visitor_identification.discovery import Discovery as VisitorIdentificationDiscovery
        return VisitorIdentificationDiscovery(self.config)

    @property
    def conversations(self):
        from .conversations.discovery import Discovery as ConversationsDiscovery
        return ConversationsDiscovery(self.config)

    @property
    def custom_channels(self):
        from .custom_channels.discovery import Discovery as CustomChannelsDiscovery
        return CustomChannelsDiscovery(self.config)



from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def invoices(self):
        from .invoices.discovery import Discovery as InvoicesDiscovery
        return InvoicesDiscovery(self.config)



class InvalidSignatureVersionError(Exception):
    def __init__(
        self, signature_version
    ):
        super().__init__(f"Invalid signature version passed to request: {signature_version}")


class InvalidSignatureTimestampError(Exception):
    def __init__(
        self, timestamp
    ):
        self.timestamp = timestamp
        super().__init__(
            f"Signature timestamp is invalid: {timestamp}."
        )



# coding: utf-8

"""
    Automation Actions V4

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.automation.actions.configuration import Configuration


class PublicActionLabels(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "input_field_descriptions": "dict[str, str]",
        "app_display_name": "str",
        "output_field_labels": "dict[str, str]",
        "input_field_option_labels": "dict[str, dict[str, str]]",
        "action_description": "str",
        "execution_rules": "dict[str, str]",
        "input_field_labels": "dict[str, str]",
        "action_name": "str",
        "action_card_content": "str",
    }

    attribute_map = {
        "input_field_descriptions": "inputFieldDescriptions",
        "app_display_name": "appDisplayName",
        "output_field_labels": "outputFieldLabels",
        "input_field_option_labels": "inputFieldOptionLabels",
        "action_description": "actionDescription",
        "execution_rules": "executionRules",
        "input_field_labels": "inputFieldLabels",
        "action_name": "actionName",
        "action_card_content": "actionCardContent",
    }

    def __init__(
        self,
        input_field_descriptions=None,
        app_display_name=None,
        output_field_labels=None,
        input_field_option_labels=None,
        action_description=None,
        execution_rules=None,
        input_field_labels=None,
        action_name=None,
        action_card_content=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicActionLabels - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._input_field_descriptions = None
        self._app_display_name = None
        self._output_field_labels = None
        self._input_field_option_labels = None
        self._action_description = None
        self._execution_rules = None
        self._input_field_labels = None
        self._action_name = None
        self._action_card_content = None
        self.discriminator = None

        if input_field_descriptions is not None:
            self.input_field_descriptions = input_field_descriptions
        if app_display_name is not None:
            self.app_display_name = app_display_name
        if output_field_labels is not None:
            self.output_field_labels = output_field_labels
        if input_field_option_labels is not None:
            self.input_field_option_labels = input_field_option_labels
        if action_description is not None:
            self.action_description = action_description
        if execution_rules is not None:
            self.execution_rules = execution_rules
        if input_field_labels is not None:
            self.input_field_labels = input_field_labels
        self.action_name = action_name
        if action_card_content is not None:
            self.action_card_content = action_card_content

    @property
    def input_field_descriptions(self):
        """Gets the input_field_descriptions of this PublicActionLabels.  # noqa: E501


        :return: The input_field_descriptions of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._input_field_descriptions

    @input_field_descriptions.setter
    def input_field_descriptions(self, input_field_descriptions):
        """Sets the input_field_descriptions of this PublicActionLabels.


        :param input_field_descriptions: The input_field_descriptions of this PublicActionLabels.  # noqa: E501
        :type input_field_descriptions: dict[str, str]
        """

        self._input_field_descriptions = input_field_descriptions

    @property
    def app_display_name(self):
        """Gets the app_display_name of this PublicActionLabels.  # noqa: E501


        :return: The app_display_name of this PublicActionLabels.  # noqa: E501
        :rtype: str
        """
        return self._app_display_name

    @app_display_name.setter
    def app_display_name(self, app_display_name):
        """Sets the app_display_name of this PublicActionLabels.


        :param app_display_name: The app_display_name of this PublicActionLabels.  # noqa: E501
        :type app_display_name: str
        """

        self._app_display_name = app_display_name

    @property
    def output_field_labels(self):
        """Gets the output_field_labels of this PublicActionLabels.  # noqa: E501


        :return: The output_field_labels of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._output_field_labels

    @output_field_labels.setter
    def output_field_labels(self, output_field_labels):
        """Sets the output_field_labels of this PublicActionLabels.


        :param output_field_labels: The output_field_labels of this PublicActionLabels.  # noqa: E501
        :type output_field_labels: dict[str, str]
        """

        self._output_field_labels = output_field_labels

    @property
    def input_field_option_labels(self):
        """Gets the input_field_option_labels of this PublicActionLabels.  # noqa: E501


        :return: The input_field_option_labels of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, dict[str, str]]
        """
        return self._input_field_option_labels

    @input_field_option_labels.setter
    def input_field_option_labels(self, input_field_option_labels):
        """Sets the input_field_option_labels of this PublicActionLabels.


        :param input_field_option_labels: The input_field_option_labels of this PublicActionLabels.  # noqa: E501
        :type input_field_option_labels: dict[str, dict[str, str]]
        """

        self._input_field_option_labels = input_field_option_labels

    @property
    def action_description(self):
        """Gets the action_description of this PublicActionLabels.  # noqa: E501


        :return: The action_description of this PublicActionLabels.  # noqa: E501
        :rtype: str
        """
        return self._action_description

    @action_description.setter
    def action_description(self, action_description):
        """Sets the action_description of this PublicActionLabels.


        :param action_description: The action_description of this PublicActionLabels.  # noqa: E501
        :type action_description: str
        """

        self._action_description = action_description

    @property
    def execution_rules(self):
        """Gets the execution_rules of this PublicActionLabels.  # noqa: E501


        :return: The execution_rules of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._execution_rules

    @execution_rules.setter
    def execution_rules(self, execution_rules):
        """Sets the execution_rules of this PublicActionLabels.


        :param execution_rules: The execution_rules of this PublicActionLabels.  # noqa: E501
        :type execution_rules: dict[str, str]
        """

        self._execution_rules = execution_rules

    @property
    def input_field_labels(self):
        """Gets the input_field_labels of this PublicActionLabels.  # noqa: E501


        :return: The input_field_labels of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._input_field_labels

    @input_field_labels.setter
    def input_field_labels(self, input_field_labels):
        """Sets the input_field_labels of this PublicActionLabels.


        :param input_field_labels: The input_field_labels of this PublicActionLabels.  # noqa: E501
        :type input_field_labels: dict[str, str]
        """

        self._input_field_labels = input_field_labels

    @property
    def action_name(self):
        """Gets the action_name of this PublicActionLabels.  # noqa: E501


        :return: The action_name of this PublicActionLabels.  # noqa: E501
        :rtype: str
        """
        return self._action_name

    @action_name.setter
    def action_name(self, action_name):
        """Sets the action_name of this PublicActionLabels.


        :param action_name: The action_name of this PublicActionLabels.  # noqa: E501
        :type action_name: str
        """
        if self.local_vars_configuration.client_side_validation and action_name is None:  # noqa: E501
            raise ValueError("Invalid value for `action_name`, must not be `None`")  # noqa: E501

        self._action_name = action_name

    @property
    def action_card_content(self):
        """Gets the action_card_content of this PublicActionLabels.  # noqa: E501


        :return: The action_card_content of this PublicActionLabels.  # noqa: E501
        :rtype: str
        """
        return self._action_card_content

    @action_card_content.setter
    def action_card_content(self, action_card_content):
        """Sets the action_card_content of this PublicActionLabels.


        :param action_card_content: The action_card_content of this PublicActionLabels.  # noqa: E501
        :type action_card_content: str
        """

        self._action_card_content = action_card_content

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicActionLabels):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicActionLabels):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Public App Crm Cards

    Allows an app to extend the CRM UI by surfacing custom cards in the sidebar of record pages. These cards are defined up-front as part of app configuration, then populated by external data fetch requests when the record page is accessed by a user.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.extensions.cards.configuration import Configuration


class IntegratorCardPayloadResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "response_version": "str",
        "card_label": "str",
        "all_items_link_url": "str",
        "total_count": "int",
        "top_level_actions": "TopLevelActions",
        "sections": "list[IntegratorObjectResult]",
    }

    attribute_map = {
        "response_version": "responseVersion",
        "card_label": "cardLabel",
        "all_items_link_url": "allItemsLinkUrl",
        "total_count": "totalCount",
        "top_level_actions": "topLevelActions",
        "sections": "sections",
    }

    def __init__(self, response_version=None, card_label=None, all_items_link_url=None, total_count=None, top_level_actions=None, sections=None, local_vars_configuration=None):  # noqa: E501
        """IntegratorCardPayloadResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._response_version = None
        self._card_label = None
        self._all_items_link_url = None
        self._total_count = None
        self._top_level_actions = None
        self._sections = None
        self.discriminator = None

        if response_version is not None:
            self.response_version = response_version
        if card_label is not None:
            self.card_label = card_label
        if all_items_link_url is not None:
            self.all_items_link_url = all_items_link_url
        self.total_count = total_count
        if top_level_actions is not None:
            self.top_level_actions = top_level_actions
        if sections is not None:
            self.sections = sections

    @property
    def response_version(self):
        """Gets the response_version of this IntegratorCardPayloadResponse.  # noqa: E501


        :return: The response_version of this IntegratorCardPayloadResponse.  # noqa: E501
        :rtype: str
        """
        return self._response_version

    @response_version.setter
    def response_version(self, response_version):
        """Sets the response_version of this IntegratorCardPayloadResponse.


        :param response_version: The response_version of this IntegratorCardPayloadResponse.  # noqa: E501
        :type response_version: str
        """
        allowed_values = ["v1", "v3"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and response_version not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `response_version` ({0}), must be one of {1}".format(response_version, allowed_values))  # noqa: E501

        self._response_version = response_version

    @property
    def card_label(self):
        """Gets the card_label of this IntegratorCardPayloadResponse.  # noqa: E501

        The label to be used for the `allItemsLinkUrl` link (e.g. 'See more tickets'). If not provided, this falls back to the card's title.  # noqa: E501

        :return: The card_label of this IntegratorCardPayloadResponse.  # noqa: E501
        :rtype: str
        """
        return self._card_label

    @card_label.setter
    def card_label(self, card_label):
        """Sets the card_label of this IntegratorCardPayloadResponse.

        The label to be used for the `allItemsLinkUrl` link (e.g. 'See more tickets'). If not provided, this falls back to the card's title.  # noqa: E501

        :param card_label: The card_label of this IntegratorCardPayloadResponse.  # noqa: E501
        :type card_label: str
        """

        self._card_label = card_label

    @property
    def all_items_link_url(self):
        """Gets the all_items_link_url of this IntegratorCardPayloadResponse.  # noqa: E501

        URL to a page the integrator has built that displays all details for this card. This URL will be displayed to users under a `See more [x]` link if there are more than five items in your response, where `[x]` is the value of `itemLabel`.  # noqa: E501

        :return: The all_items_link_url of this IntegratorCardPayloadResponse.  # noqa: E501
        :rtype: str
        """
        return self._all_items_link_url

    @all_items_link_url.setter
    def all_items_link_url(self, all_items_link_url):
        """Sets the all_items_link_url of this IntegratorCardPayloadResponse.

        URL to a page the integrator has built that displays all details for this card. This URL will be displayed to users under a `See more [x]` link if there are more than five items in your response, where `[x]` is the value of `itemLabel`.  # noqa: E501

        :param all_items_link_url: The all_items_link_url of this IntegratorCardPayloadResponse.  # noqa: E501
        :type all_items_link_url: str
        """

        self._all_items_link_url = all_items_link_url

    @property
    def total_count(self):
        """Gets the total_count of this IntegratorCardPayloadResponse.  # noqa: E501

        The total number of card properties that will be sent in this response.  # noqa: E501

        :return: The total_count of this IntegratorCardPayloadResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this IntegratorCardPayloadResponse.

        The total number of card properties that will be sent in this response.  # noqa: E501

        :param total_count: The total_count of this IntegratorCardPayloadResponse.  # noqa: E501
        :type total_count: int
        """
        if self.local_vars_configuration.client_side_validation and total_count is None:  # noqa: E501
            raise ValueError("Invalid value for `total_count`, must not be `None`")  # noqa: E501

        self._total_count = total_count

    @property
    def top_level_actions(self):
        """Gets the top_level_actions of this IntegratorCardPayloadResponse.  # noqa: E501


        :return: The top_level_actions of this IntegratorCardPayloadResponse.  # noqa: E501
        :rtype: TopLevelActions
        """
        return self._top_level_actions

    @top_level_actions.setter
    def top_level_actions(self, top_level_actions):
        """Sets the top_level_actions of this IntegratorCardPayloadResponse.


        :param top_level_actions: The top_level_actions of this IntegratorCardPayloadResponse.  # noqa: E501
        :type top_level_actions: TopLevelActions
        """

        self._top_level_actions = top_level_actions

    @property
    def sections(self):
        """Gets the sections of this IntegratorCardPayloadResponse.  # noqa: E501

        A list of up to five valid card sub categories.  # noqa: E501

        :return: The sections of this IntegratorCardPayloadResponse.  # noqa: E501
        :rtype: list[IntegratorObjectResult]
        """
        return self._sections

    @sections.setter
    def sections(self, sections):
        """Sets the sections of this IntegratorCardPayloadResponse.

        A list of up to five valid card sub categories.  # noqa: E501

        :param sections: The sections of this IntegratorCardPayloadResponse.  # noqa: E501
        :type sections: list[IntegratorObjectResult]
        """

        self._sections = sections

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegratorCardPayloadResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IntegratorCardPayloadResponse):
            return True

        return self.to_dict() != other.to_dict()
